@@ -1,8 +1,8 @@
 class Clojure < Formula
   desc "The Clojure Programming Language"
   homepage "https://clojure.org"
-  url "https://download.clojure.org/install/clojure-tools-1.10.1.561.tar.gz"
-  sha256 "46c193d09f8fce9c0e5e530c2463586cec9717593cdee2f57199d278ed104e2d"
+  url "https://download.clojure.org/install/clojure-tools-1.10.1.708.tar.gz"
+  sha256 "e200f3e148918a12226026809f052f1be54bd43d490bb079072182488155dbc9"
   license "EPL-1.0"
 
   bottle :unneeded
@@ -17,9 +17,9 @@ class Clojure < Formula
 
   test do
     ENV["TERM"] = "xterm"
-    system("#{bin}/clj -e nil")
+    system("#{bin}/clj -M -e nil")
     %w[clojure clj].each do |clj|
-      assert_equal "2", shell_output("#{bin}/#{clj} -e \"(+ 1 1)\"").strip
+      assert_equal "2", shell_output("#{bin}/#{clj} -M -e \"(+ 1 1)\"").strip
     end
   end
 end
