@@ -1,7 +1,7 @@
-class ClojureAT1101697 < Formula
+class ClojureAT1101716 < Formula
   desc "The Clojure Programming Language"
   homepage "https://clojure.org"
-  url "https://download.clojure.org/install/clojure-tools-1.10.1.697.tar.gz"
+  url "https://download.clojure.org/install/clojure-tools-1.10.1.716.tar.gz"
   sha256 "SHA"
   license "EPL-1.0"
 
@@ -17,9 +17,9 @@ class ClojureAT1101697 < Formula
 
   test do
     ENV["TERM"] = "xterm"
-    system("#{bin}/clj -e nil")
+    system("#{bin}/clj -M -e nil")
     %w[clojure clj].each do |clj|
-      assert_equal "2", shell_output("#{bin}/#{clj} -e \"(+ 1 1)\"").strip
+      assert_equal "2", shell_output("#{bin}/#{clj} -M -e \"(+ 1 1)\"").strip
     end
   end
 end
